@@ -1,6 +1,5 @@
 """Reference model for the API of the Jupyter Notebook interface."""
 
-
 from typing import List
 from typing import Optional
 from typing import Tuple
@@ -12,7 +11,7 @@ from _plotly_utils.colors.carto import Teal_r
 from _plotly_utils.colors.qualitative import Plotly as PlotlyColors
 from pydantic import BaseModel
 from pydantic import Field
-from pydantic import validator
+from pydantic.functional_validators import field_validator
 
 
 class XAxisAPI(BaseModel):
@@ -113,12 +112,13 @@ class ColorAPI(BaseModel):
     components: str = Field(
         default=PlotlyColors[6], description="Color of the components, mainly peaks."
     )
-    # Merging two color list to onw list with switchin the order of the colors
     bars: List[str] = Field(
         default=[i for j in zip(Teal_r, Purp_r) for i in j],
         description="Color of the bar plot of the metrics.",
     )
-    lines: List[str] = Field(default=Burg, description="Color of the lines plot.")
+    lines: List[str] = Field(
+        default=Burg, description="Color of the lines of the plot."
+    )
     paper: str = Field(default="white", description="Color of the paper.")
     plot: str = Field(default="white", description="Color of the plot.")
     color: str = Field(default="black", description="Color of the text.")
@@ -128,8 +128,8 @@ class ColorAPI(BaseModel):
     ticks: str = Field(default="black", description="Color of the ticks.")
     font: str = Field(default="black", description="Font color of the plot.")
 
-    @validator(
-        "page",
+    @field_validator(
+        "paper",
         "layout",
         "grid",
         "line",
