@@ -1,4 +1,5 @@
 """Reference model for the API of the Jupyter Notebook report."""
+
 from typing import Any
 from typing import Dict
 from typing import Hashable
@@ -14,6 +15,7 @@ from numpy import __version__ as numpy_version
 from pandas import __version__ as pandas_version
 from plotly import __version__ as plotly_version
 from pydantic import BaseModel
+from pydantic import ConfigDict
 from pydantic import Field
 from pydantic import __version__ as pydantic_version
 from scipy import __version__ as scipy_version
@@ -23,7 +25,7 @@ from spectrafit.api.tools_model import DataPreProcessingAPI
 from statsmodels import __version__ as statsmodels_version
 
 
-class CreditsAPI(BaseModel, frozen=True):
+class CreditsAPI(BaseModel):
     """Credits API model."""
 
     dtale: str = f"dtale v{dtale_version}"
@@ -47,13 +49,17 @@ class FitMethodAPI(BaseModel):
         default=False,
         description="Fitting in the global fashion",
     )
-    confidence_interval: Dict[str, Any] = Field(
+    confidence_interval: Union[bool, Dict[str, Any]] = Field(
         ...,
         description="Settings for the confidence interval calculation",
     )
     configurations: Dict[str, Any] = Field(
         ..., description="Settings for the fitting configuration"
     )
+    settings_solver_models: Dict[str, Any] = Field(
+        ...,
+        description="Settings for the solver models including minimizer and optimizer",
+    )
 
 
 class InputAPI(BaseModel):
@@ -101,6 +107,10 @@ class SolverAPI(BaseModel):
         default={},
         description="Error bar comment if values reach initial value or boundary",
     )
+    computional: Dict[str, Any] = Field(
+        ...,
+        description="Computional information like number of function evaluations",
+    )
 
 
 class OutputAPI(BaseModel):
@@ -118,11 +128,7 @@ class OutputAPI(BaseModel):
         default={},
         description="DataFrame of the pre-processed data via 'records' orient",
     )
-
-    class Config:
-        """Config for the OutputAPI of arbitary types."""
-
-        arbitrary_types_allowed = True
+    model_config = ConfigDict(arbitrary_types_allowed=True)
 
 
 class ReportAPI(BaseModel):
