@@ -1,4 +1,5 @@
 """Minimization models for curve fitting."""
+
 from collections import defaultdict
 from dataclasses import dataclass
 from math import log
@@ -46,8 +47,8 @@ class DistributionModels:
         `sigma` parameter.
     """
 
+    @staticmethod
     def gaussian(
-        self,
         x: NDArray[np.float64],
         amplitude: float = 1.0,
         center: float = 0.0,
@@ -77,8 +78,8 @@ class DistributionModels:
             -((1.0 * x - center) ** 2) / (2 * sigma**2)
         )
 
+    @staticmethod
     def lorentzian(
-        self,
         x: NDArray[np.float64],
         amplitude: float = 1.0,
         center: float = 0.0,
@@ -109,8 +110,8 @@ class DistributionModels:
             pi * sigma
         )
 
+    @staticmethod
     def voigt(
-        self,
         x: NDArray[np.float64],
         center: float = 0.0,
         fwhmv: float = 1.0,
@@ -142,8 +143,8 @@ class DistributionModels:
         z = (x - center + 1j * gamma) / (sigma * Constants.sq2)
         return np.array(wofz(z).real / (sigma * Constants.sq2pi))
 
+    @staticmethod
     def pseudovoigt(
-        self,
         x: NDArray[np.float64],
         amplitude: float = 1.0,
         center: float = 0.0,
@@ -186,13 +187,18 @@ class DistributionModels:
             + 0.11116 * (fwhml / f) ** 3
         )
         return np.array(
-            n * self.lorentzian(x=x, amplitude=amplitude, center=center, fwhml=fwhml)
+            n
+            * DistributionModels.lorentzian(
+                x=x, amplitude=amplitude, center=center, fwhml=fwhml
+            )
             + (1 - n)
-            * self.gaussian(x=x, amplitude=amplitude, center=center, fwhmg=fwhmg)
+            * DistributionModels.gaussian(
+                x=x, amplitude=amplitude, center=center, fwhmg=fwhmg
+            )
         )
 
+    @staticmethod
     def exponential(
-        self,
         x: NDArray[np.float64],
         amplitude: float = 1.0,
         decay: float = 1.0,
@@ -213,8 +219,8 @@ class DistributionModels:
         """
         return np.array(amplitude * np.exp(-x / decay) + intercept)
 
+    @staticmethod
     def power(
-        self,
         x: NDArray[np.float64],
         amplitude: float = 1.0,
         exponent: float = 1.0,
@@ -235,8 +241,8 @@ class DistributionModels:
         """
         return np.array(amplitude * np.power(x, exponent) + intercept)
 
+    @staticmethod
     def linear(
-        self,
         x: NDArray[np.float64],
         slope: float = 1.0,
         intercept: float = 0.0,
@@ -254,8 +260,8 @@ class DistributionModels:
         """
         return np.array(slope * x + intercept)
 
+    @staticmethod
     def constant(
-        self,
         x: NDArray[np.float64],
         amplitude: float = 1.0,
     ) -> NDArray[np.float64]:
@@ -288,8 +294,8 @@ class DistributionModels:
             sigma = 1.0e-13
         return np.subtract(x, center) / sigma
 
+    @staticmethod
     def erf(
-        self,
         x: NDArray[np.float64],
         amplitude: float = 1.0,
         center: float = 0.0,
@@ -311,10 +317,12 @@ class DistributionModels:
         Returns:
             NDArray[np.float64]: Error function of `x` given.
         """
-        return np.array(amplitude * 0.5 * (1 + erf(self._norm(x, center, sigma))))
+        return np.array(
+            amplitude * 0.5 * (1 + erf(DistributionModels._norm(x, center, sigma)))
+        )
 
+    @staticmethod
     def heaviside(
-        self,
         x: NDArray[np.float64],
         amplitude: float = 1.0,
         center: float = 0.0,
@@ -342,10 +350,12 @@ class DistributionModels:
         Returns:
             NDArray[np.float64]: Heaviside step function of `x` given.
         """
-        return np.array(amplitude * 0.5 * (1 + np.sign(self._norm(x, center, sigma))))
+        return np.array(
+            amplitude * 0.5 * (1 + np.sign(DistributionModels._norm(x, center, sigma)))
+        )
 
+    @staticmethod
     def atan(
-        self,
         x: NDArray[np.float64],
         amplitude: float = 1.0,
         center: float = 0.0,
@@ -370,11 +380,13 @@ class DistributionModels:
             NDArray[np.float64]: Arctan step function of `x` given.
         """
         return np.array(
-            amplitude * 0.5 * (1 + np.arctan(self._norm(x, center, sigma)) / pi)
+            amplitude
+            * 0.5
+            * (1 + np.arctan(DistributionModels._norm(x, center, sigma)) / pi)
         )
 
+    @staticmethod
     def log(
-        self,
         x: NDArray[np.float64],
         amplitude: float = 1.0,
         center: float = 0.0,
@@ -399,11 +411,13 @@ class DistributionModels:
             NDArray[np.float64]: Logarithmic step function of `x` given.
         """
         return np.array(
-            amplitude * 0.5 * (1 + np.log(self._norm(x, center, sigma)) / pi)
+            amplitude
+            * 0.5
+            * (1 + np.log(DistributionModels._norm(x, center, sigma)) / pi)
         )
 
+    @staticmethod
     def cgaussian(
-        self,
         x: NDArray[np.float64],
         amplitude: float = 1.0,
         center: float = 0.0,
@@ -432,8 +446,8 @@ class DistributionModels:
             amplitude * 0.5 * (1 + erf((x - center) / (sigma * np.sqrt(2.0))))
         )
 
+    @staticmethod
     def clorentzian(
-        self,
         x: NDArray[np.float64],
         amplitude: float = 1.0,
         center: float = 0.0,
@@ -460,8 +474,8 @@ class DistributionModels:
         sigma = fwhml * Constants.fwhml2sig
         return np.array(amplitude * (np.arctan((x - center) / sigma) / pi) + 0.5)
 
+    @staticmethod
     def cvoigt(
-        self,
         x: NDArray[np.float64],
         amplitude: float = 1.0,
         center: float = 0.0,
@@ -494,12 +508,234 @@ class DistributionModels:
             * np.exp(-(((x - center) / gamma) ** 2))
         )
 
+    @staticmethod
+    def polynom2(
+        x: NDArray[np.float64],
+        coefficient0: float = 1.0,
+        coefficient1: float = 1.0,
+        coefficient2: float = 1.0,
+    ) -> NDArray[np.float64]:
+        """Return a 1-dimensional second order polynomial function.
+
+        $$
+        f(x) = c_2 x^2 + c_1 x + c_0
+        $$
+
+        Args:
+            x (NDArray[np.float64]): `x`-values of the data
+            coefficient0 (float, optional): Zeroth coefficient of the
+                 polynomial function. Defaults to 1.0.
+            coefficient1 (float, optional): First coefficient of the
+                 polynomial function. Defaults to 1.0.
+            coefficient2 (float, optional): Second coefficient of the
+                 polynomial function. Defaults to 1.0.
+
+        Returns:
+            NDArray[np.float64]: Third order polynomial function of `x`
+        """
+        return np.array(coefficient0 + coefficient1 * x + coefficient2 * x**2)
+
+    @staticmethod
+    def polynom3(
+        x: NDArray[np.float64],
+        coefficient0: float = 1.0,
+        coefficient1: float = 1.0,
+        coefficient2: float = 1.0,
+        coefficient3: float = 1.0,
+    ) -> NDArray[np.float64]:
+        """Return a 1-dimensional third order polynomial function.
+
+        $$
+        f(x) = c_3 x^3 + c_2 x^2 + c_1 x + c_0
+        $$
+
+        Args:
+            x (NDArray[np.float64]): `x`-values of the data
+            coefficient0 (float, optional): Zeroth coefficient of the
+                 polynomial function. Defaults to 1.0.
+            coefficient1 (float, optional): First coefficient of the
+                 polynomial function. Defaults to 1.0.
+            coefficient2 (float, optional): Second coefficient of the
+                 polynomial function. Defaults to 1.0.
+            coefficient3 (float, optional): Third coefficient of the
+                 polynomial function. Defaults to 1.0.
+
+        Returns:
+            NDArray[np.float64]: Third order polynomial function of `x`
+        """
+        return np.array(
+            coefficient0 + coefficient1 * x + coefficient2 * x**2 + coefficient3 * x**3
+        )
+
+    @staticmethod
+    def pearson1(
+        x: NDArray[np.float64],
+        amplitude: float = 1.0,
+        center: float = 0.0,
+        sigma: float = 1.0,
+        exponent: float = 1.0,
+    ) -> NDArray[np.float64]:
+        r"""Return a 1-dimensional Pearson type I distribution.
+
+        $$
+        f(x) = \frac{A}{\sigma \sqrt{2 \pi}} \left[1 + \frac{(x - c)^2}{\sigma^2}
+        \right]^{-\frac{1}{\nu}}
+        $$
+
+        Args:
+            x (NDArray[np.float64]): `x`-values of the data.
+            amplitude (float, optional): Amplitude of the Pearson type I function.
+                    Defaults to 1.0.
+            center (float, optional): Center of the Pearson type I function.
+                 Defaults to 0.0.
+            sigma (float, optional): Sigma of the Pearson type I function.
+                 Defaults to 1.0.
+            exponent (float, optional): Exponent of the Pearson type I function.
+                 Defaults to 1.0.
+
+        Returns:
+            NDArray[np.float64]: Pearson type I function of `x` given.
+        """
+        return np.array(
+            amplitude
+            / (sigma * np.sqrt(2 * np.pi))
+            * np.power(1 + ((x - center) / sigma) ** 2, -1 / exponent)
+        )
+
+    @staticmethod
+    def pearson2(
+        x: NDArray[np.float64],
+        amplitude: float = 1.0,
+        center: float = 0.0,
+        sigma: float = 1.0,
+        exponent: float = 1.0,
+    ) -> NDArray[np.float64]:
+        r"""Return a 1-dimensional Pearson type II distribution.
+
+        $$
+        f(x) = \frac{A}{\sigma \sqrt{2 \pi}} \left[1 + \frac{(x - c)^2}{2 \sigma^2}
+        \right]^{-\nu}
+        $$
+
+        Args:
+            x (NDArray[np.float64]): `x`-values of the data.
+            amplitude (float, optional): Amplitude of the Pearson type II function.
+                    Defaults to 1.0.
+            center (float, optional): Center of the Pearson type II function.
+                 Defaults to 0.0.
+            sigma (float, optional): Sigma of the Pearson type II function.
+                 Defaults to 1.0.
+            exponent (float, optional): Exponent of the Pearson type II function.
+                 Defaults to 1.0.
+
+        Returns:
+            NDArray[np.float64]: Pearson type II function of `x` given.
+        """
+        return np.array(
+            amplitude
+            / (sigma * np.sqrt(2 * pi))
+            * np.power(1 + ((x - center) / (2 * sigma)) ** 2, -exponent)
+        )
+
+    @staticmethod
+    def pearson3(
+        x: NDArray[np.float64],
+        amplitude: float = 1.0,
+        center: float = 0.0,
+        sigma: float = 1.0,
+        exponent: float = 1.0,
+        skewness: float = 0.0,
+    ) -> NDArray[np.float64]:
+        r"""Return a 1-dimensional Pearson type III distribution.
+
+        $$
+        f(x) = \frac{A}{\sigma \sqrt{2 \pi}} \left[1 + \frac{(x - c)^2}{2 \sigma^2}
+        \right]^{-\nu} \left[1 + \frac{\gamma}{\nu}
+        \frac{x - c}{\sigma} \right]^{-\nu - 1}
+        $$
+
+        Args:
+            x (NDArray[np.float64]): `x`-values of the data.
+            amplitude (float, optional): Amplitude of the Pearson type III function.
+                    Defaults to 1.0.
+            center (float, optional): Center of the Pearson type III function.
+                 Defaults to 0.0.
+            sigma (float, optional): Sigma of the Pearson type III function.
+                 Defaults to 1.0.
+            exponent (float, optional): Exponent of the Pearson type III function.
+                 Defaults to 1.0.
+            skewness (float, optional): Skewness of the Pearson type III function.
+                 Defaults to 0.0.
+
+        Returns:
+            NDArray[np.float64]: Pearson type III function of `x` given.
+        """
+        return np.array(
+            amplitude
+            / (sigma * np.sqrt(2 * pi))
+            * np.power(1 + ((x - center) / (2 * sigma)) ** 2, -exponent)
+            * np.power(
+                1 + (skewness / exponent) * ((x - center) / sigma), -exponent - 1
+            )
+        )
+
+    @staticmethod
+    def pearson4(
+        x: NDArray[np.float64],
+        amplitude: float = 1.0,
+        center: float = 0.0,
+        sigma: float = 1.0,
+        exponent: float = 1.0,
+        skewness: float = 0.0,
+        kurtosis: float = 0.0,
+    ) -> NDArray[np.float64]:
+        r"""Return a 1-dimensional Pearson type IV distribution.
+
+        $$
+        f(x) = \frac{A}{\sigma \sqrt{2 \pi}} \left[1 + \frac{(x - c)^2}{2 \sigma^2}
+        \right]^{-\nu} \left[1 + \frac{\gamma}{\nu}
+        \frac{x - c}{\sigma} \right]^{-\nu - 1}
+        \left[1 + \frac{\delta}{\nu}
+        \left(\frac{x - c}{\sigma}\right)^2 \right]^{-\nu - 1/2}
+        $$
+
+        Args:
+            x (NDArray[np.float64]): `x`-values of the data.
+            amplitude (float, optional): Amplitude of the Pearson type IV function.
+                    Defaults to 1.0.
+            center (float, optional): Center of the Pearson type IV function.
+                 Defaults to 0.0.
+            sigma (float, optional): Sigma of the Pearson type IV function.
+                 Defaults to 1.0.
+            exponent (float, optional): Exponent of the Pearson type IV function.
+                 Defaults to 1.0.
+            skewness (float, optional): Skewness of the Pearson type IV function.
+                 Defaults to 0.0.
+            kurtosis (float, optional): Kurtosis of the Pearson type IV function.
+                 Defaults to 0.0.
+
+        Returns:
+            NDArray[np.float64]: Pearson type IV function of `x` given.
+        """
+        return np.array(
+            amplitude
+            / (sigma * np.sqrt(2 * pi))
+            * np.power(1 + ((x - center) / (2 * sigma)) ** 2, -exponent)
+            * np.power(
+                1 + (skewness / exponent) * ((x - center) / sigma), -exponent - 1
+            )
+            * np.power(
+                1 + (kurtosis / exponent) * ((x - center) / sigma) ** 2,
+                -exponent - 1 / 2,
+            )
+        )
+
 
 @dataclass(frozen=True)
 class ReferenceKeys:
     """Reference keys for model fitting and peak detection."""
 
-    __models__ = list(DistributionModelAPI.schema()["properties"].keys())
+    __models__ = list(DistributionModelAPI.model_json_schema()["properties"].keys())
 
     __automodels__ = [
         "gaussian",
@@ -515,7 +751,7 @@ class ReferenceKeys:
             model (str): Model name.
 
         Raises:
-            KeyError: If the model is not supported.
+            NotImplementedError: If the model is not implemented.
         """
         if model.split("_")[0] not in self.__models__:
             raise NotImplementedError(f"{model} is not supported!")
@@ -991,9 +1227,9 @@ class ModelParameters(AutoPeakDetection):
         positions, properties = self.__autodetect__()
         if (
             not isinstance(self.args["autopeak"], bool)
-            and "model_type" in self.args["autopeak"]
+            and "modeltype" in self.args["autopeak"]
         ):
-            _model = self.args["autopeak"]["model_type"].lower()
+            _model = self.args["autopeak"]["modeltype"].lower()
             ReferenceKeys().automodel_check(model=_model)
             models = _model
         else:
@@ -1217,12 +1453,12 @@ class ModelParameters(AutoPeakDetection):
         if col_i:
             if key_3 != "amplitude":
                 self.params.add(
-                    f"{key_2}_{key_3}_{key_1}_{col_i+1}",
+                    f"{key_2}_{key_3}_{key_1}_{col_i + 1}",
                     expr=f"{key_2}_{key_3}_{key_1}_1",
                 )
             else:
                 self.params.add(
-                    f"{key_2}_{key_3}_{key_1}_{col_i+1}",
+                    f"{key_2}_{key_3}_{key_1}_{col_i + 1}",
                     **value_3,
                 )
 
@@ -1269,8 +1505,8 @@ class SolverModels(ModelParameters):
                  additional information beyond the command line arguments.
         """
         super().__init__(df=df, args=args)
-        self.args_solver = SolverModelsAPI(**args).dict()
-        self.args_global = GlobalFittingAPI(**args).dict()
+        self.args_solver = SolverModelsAPI(**args).model_dump()
+        self.args_global = GlobalFittingAPI(**args).model_dump()
         self.params = self.return_params
 
     def __call__(self) -> Tuple[Minimizer, Any]:
@@ -1294,7 +1530,11 @@ class SolverModels(ModelParameters):
                 **self.args_solver["minimizer"],
             )
 
-        return (minimizer, minimizer.minimize(**self.args_solver["optimizer"]))
+        result = minimizer.minimize(
+            **self.args_solver["optimizer"],
+        )
+        self.args_solver["optimizer"]["max_nfev"] = minimizer.max_nfev
+        return minimizer, result
 
     @staticmethod
     def solve_local_fitting(
