@@ -1,7 +1,18 @@
-"""Plotting of the fit results."""
+"""Plotting of the fit results.
+
+!!! info "About the Font Cache"
+
+    For avoiding problems with the font cache, the font cache is rebuilt at the
+    beginning of the program. This can take a few seconds. If you want to avoid
+    this, you can comment out the line `matplotlib.font_manager._rebuild()` in
+    the `plotting.py` file.
+"""
+
 from typing import Any
 from typing import Dict
+from typing import Optional
 
+import matplotlib.font_manager
 import matplotlib.pyplot as plt
 import pandas as pd
 import seaborn as sns
@@ -10,6 +21,8 @@ from matplotlib.widgets import MultiCursor
 from spectrafit.api.tools_model import ColumnNamesAPI
 
 
+matplotlib.font_manager.findfont("serif", rebuild_if_missing=True)
+
 sns.set_theme(style="whitegrid")
 color = sns.color_palette("Paired")
 
@@ -17,28 +30,30 @@ color = sns.color_palette("Paired")
 class PlotSpectra:
     """Plotting of the fit results."""
 
-    def __init__(self, df: pd.DataFrame, args: Dict[str, Any]) -> None:
+    def __init__(self, df: pd.DataFrame, args: Optional[Dict[str, Any]] = None) -> None:
         """Initialize the PlotSpectra class.
 
         Args:
             df (pd.DataFrame): DataFrame containing the input data (`x` and `data`),
                  as well as the best fit and the corresponding residuum. Hence, it will
                  be extended by the single contribution of the model.
-            args (Dict[str, Any]): The input file arguments as a dictionary with
-                 additional information beyond the command line arguments.
+            args (Dict[str, Any], optional): The input file arguments as a dictionary
+                 with additional information beyond the command line arguments. Only
+                 needed for global fitting. Defaults to None.
         """
         self.df = df
         self.args = args
 
     def __call__(self) -> None:
         """Plot the data and the fit."""
-        if not self.args["noplot"]:
-            if self.args["global_"]:
-                self.plot_global_spectra
-            else:
-                self.plot_local_spectra
+        if self.args is not None:
+            if not self.args["noplot"]:
+                if self.args["global_"]:
+                    self.plot_global_spectra()
+                else:
+                    self.plot_local_spectra()
+            plt.show()
 
-    @property
     def plot_global_spectra(self) -> None:
         """Plot spectra for global fitting.
 
@@ -49,7 +64,7 @@ class PlotSpectra:
             row of the grid plot contains the residuals of each single fit, the
             second row the best fit of the model with single peak contributions.
         """
-        n_spec = len(list(self.args["data_statistic"])) - 1
+        n_spec: int = len(list(self.args["data_statistic"])) - 1 if self.args else 1
         _, axs = plt.subplots(
             nrows=2,
             ncols=n_spec,
@@ -59,24 +74,24 @@ class PlotSpectra:
         )
 
         for i in range(n_spec):
-            axs[0, i].set_title(f"Spectrum #{i+1}")
+            axs[0, i].set_title(f"Spectrum #{i + 1}")
             sns.regplot(
                 x=ColumnNamesAPI().energy,
-                y=f"{ColumnNamesAPI().residual}_{i+1}",
+                y=f"{ColumnNamesAPI().residual}_{i + 1}",
                 data=self.df,
                 ax=axs[0, i],
                 color=color[5],
             )
             axs[1, i] = sns.lineplot(
                 x=ColumnNamesAPI().energy,
-                y=f"{ColumnNamesAPI().intensity}_{i+1}",
+                y=f"{ColumnNamesAPI().intensity}_{i + 1}",
                 data=self.df,
                 ax=axs[1, i],
                 color=color[1],
             )
             axs[1, i] = sns.lineplot(
                 x=ColumnNamesAPI().energy,
-                y=f"fit_{i+1}",
+                y=f"fit_{i + 1}",
                 data=self.df,
                 ax=axs[1, i],
                 ls="--",
@@ -85,8 +100,8 @@ class PlotSpectra:
             peaks = [
                 peak
                 for peak in self.df.columns
-                if not peak.startswith(tuple(ColumnNamesAPI().dict().values()))
-                and peak.endswith(f"_{i+1}")
+                if not peak.startswith(tuple(ColumnNamesAPI().model_dump().values()))
+                and peak.endswith(f"_{i + 1}")
             ]
             color_peaks = sns.color_palette("rocket", len(peaks))
             for j, peak in enumerate(peaks):
@@ -100,9 +115,7 @@ class PlotSpectra:
                 )
 
         plt.tight_layout()
-        plt.show()
 
-    @property
     def plot_local_spectra(self) -> None:
         """Plot spectra for local fitting.
 
@@ -153,7 +166,7 @@ class PlotSpectra:
         peaks = [
             peak
             for peak in self.df.columns
-            if peak not in list(ColumnNamesAPI().dict().values())
+            if peak not in list(ColumnNamesAPI().model_dump().values())
         ]
         color_peaks = sns.color_palette("rocket", len(peaks))
         for i, peak in enumerate(peaks):
@@ -169,4 +182,3 @@ class PlotSpectra:
         _ = MultiCursor(
             fig.canvas, (ax1, ax2), color=color[4], ls="--", lw=1, horizOn=True
         )
-        plt.show()
