@@ -39,16 +39,19 @@ from spectrafit.api.report_model import ReportAPI
 from spectrafit.api.report_model import SolverAPI
 from spectrafit.api.tools_model import ColumnNamesAPI
 from spectrafit.api.tools_model import DataPreProcessingAPI
+from spectrafit.api.tools_model import SolverModelsAPI
 from spectrafit.models import SolverModels
 from spectrafit.tools import PostProcessing
 from spectrafit.tools import PreProcessing
+from spectrafit.tools import exclude_none_dictionary
+from spectrafit.tools import transform_nested_types
 from spectrafit.utilities.transformer import list2dict
 
 
 class DataFrameDisplay:
     """Class for displaying a dataframe in different ways."""
 
-    def df_display(self, df: pd.DataFrame, mode: Optional[str] = None) -> None:
+    def df_display(self, df: pd.DataFrame, mode: Optional[str] = None) -> Optional[Any]:
         """Call the DataframeDisplay class.
 
         !!! info "About `df_display`"
@@ -75,6 +78,10 @@ class DataFrameDisplay:
 
         Raises:
             ValueError: Raises ValueError if mode of displaying is not supported.
+
+        Returns:
+            Optional[Any]: Returns the dtale object for plotting in the Jupyter
+                 notebook, if mode is `dtale`.
         """
         if mode == "regular":
             self.regular_display(df=df)
@@ -83,12 +90,13 @@ class DataFrameDisplay:
         elif mode == "interactive":
             self.interactive_display(df=df)
         elif mode == "dtale":
-            self.dtale_display(df=df)
+            return self.dtale_display(df=df)
         elif mode is not None:
             raise ValueError(
                 f"Invalid mode: {mode}. "
                 "Valid modes are: regular, interactive, dtale, markdown."
             )
+        return None
 
     @staticmethod
     def regular_display(df: pd.DataFrame) -> None:
@@ -109,13 +117,16 @@ class DataFrameDisplay:
         itables_show(df)
 
     @staticmethod
-    def dtale_display(df: pd.DataFrame) -> None:
+    def dtale_display(df: pd.DataFrame) -> Any:
         """Display the dataframe in a dtale way.
 
         Args:
             df (pd.DataFrame): Dataframe to display.
+
+        Returns:
+            Any: Returns the dtale object for plotting in the Jupyter notebook.
         """
-        dtale_show(df)
+        return dtale_show(df)
 
     @staticmethod
     def markdown_display(df: pd.DataFrame) -> None:
@@ -225,7 +236,13 @@ class DataFramePlot:
         else:
             fig.update_yaxes(title_text=yaxis_title, row=1, col=1)
         fig.update_yaxes(title_text=yaxis_title, row=2, col=1)
-        fig.show()
+        fig.show(
+            config={
+                "toImageButtonOptions": dict(
+                    format="png", filename="plot_of_2_dataframes", scale=4
+                )
+            }
+        )
 
     def plot_dataframe(self, args_plot: PlotAPI, df: pd.DataFrame) -> None:
         """Plot the dataframe according to the PlotAPI arguments.
@@ -247,7 +264,13 @@ class DataFramePlot:
                 name=args_plot.yaxis_title.name, unit=args_plot.yaxis_title.unit
             )
         )
-        fig.show()
+        fig.show(
+            config={
+                "toImageButtonOptions": dict(
+                    format="png", filename="plot_dataframe", scale=4
+                )
+            }
+        )
 
     def plot_global_fit(self, args_plot: PlotAPI, df: pd.DataFrame) -> None:
         """Plot the global dataframe according to the PlotAPI arguments.
@@ -258,7 +281,7 @@ class DataFramePlot:
         """
         for i in range(
             1,
-            sum(1 for _col in df.columns if _col.startswith(ColumnNamesAPI().fit)) + 1,
+            sum(bool(_col.startswith(ColumnNamesAPI().fit)) for _col in df.columns) + 1,
         ):
             _col = [col for col in df.columns if col.endswith(str(i))]
             _col.append(ColumnNamesAPI().energy)
@@ -322,7 +345,13 @@ class DataFramePlot:
             ),
             secondary_y=True,
         )
-        fig.show()
+        fig.show(
+            config={
+                "toImageButtonOptions": dict(
+                    format="png", filename="plot_metric", scale=4
+                )
+            }
+        )
 
     def update_layout_axes(
         self, fig: Figure, args_plot: PlotAPI, height: int
@@ -340,8 +369,8 @@ class DataFramePlot:
         fig.update_layout(
             title=args_plot.title,
             legend_title=args_plot.legend_title,
-            legend=args_plot.legend.dict(),
-            font=args_plot.font.dict(),
+            legend=args_plot.legend.model_dump(),
+            font=args_plot.font.model_dump(),
             showlegend=args_plot.show_legend,
             width=args_plot.size[0],
             height=height,
@@ -568,6 +597,15 @@ class SolverResults:
         """
         return self.args_out["linear_correlation"]
 
+    @property
+    def get_computional(self) -> Dict[str, Any]:
+        """Get the computational time.
+
+        Returns:
+            Dict[str, Any]: Computational time as dictionary.
+        """
+        return self.args_out["fit_insights"]["computional"]
+
     @property
     def settings_conf_interval(self) -> Union[bool, Dict[str, Any]]:
         """Confidence interval settings.
@@ -628,6 +666,7 @@ class ExportReport(SolverResults):
         description: DescriptionAPI,
         initial_model: List[Dict[str, Dict[str, Dict[str, Any]]]],
         pre_processing: DataPreProcessingAPI,
+        settings_solver_models: SolverModelsAPI,
         fname: FnameAPI,
         args_out: Dict[str, Any],
         df_org: pd.DataFrame,
@@ -641,6 +680,7 @@ class ExportReport(SolverResults):
             initial_model (List[Dict[str, Dict[str, Dict[str, Any]]]]): Initial model
                  for the fit.
             pre_processing (DataPreProcessingAPI): Data pre-processing settings.
+            settings_solver_models (SolverModelsAPI): Solver models settings.
             fname (FnameAPI): Filename of the fit project including the path, prefix,
                  and suffix.
             args_out (Dict[str, Any]): Dictionary of SpectraFit settings and results.
@@ -654,6 +694,7 @@ class ExportReport(SolverResults):
         self.description = description
         self.initial_model = initial_model
         self.pre_processing = pre_processing
+        self.settings_solver_models = settings_solver_models
         self.fname = fname
 
         self.df_org = df_org.to_dict(orient="list")
@@ -675,6 +716,9 @@ class ExportReport(SolverResults):
                 global_fitting=self.settings_global_fitting,
                 confidence_interval=self.settings_conf_interval,
                 configurations=self.settings_configurations,
+                settings_solver_models=self.settings_solver_models.model_dump(
+                    exclude_none=True
+                ),
             ),
         )
 
@@ -695,6 +739,7 @@ class ExportReport(SolverResults):
             covariance_matrix=self.get_covariance_matrix,
             variables=self.get_variables,
             errorbars=self.get_errorbars,
+            computional=self.get_computional,
         )
 
     @property
@@ -709,15 +754,26 @@ class ExportReport(SolverResults):
     def __call__(self) -> Dict[str, Any]:
         """Get the complete report as dictionary.
 
+        !!! info "About the report and `exclude_none_dictionary`"
+
+            The report is generated by using the `ReportAPI` class, which is a
+            `Pydantic`-definition of the report. The `Pydantic`-definition is
+            converted to a dictionary by using the `.model_dump()` option of `Pydantic`.
+            The `recursive_exclude_none` function is used to remove all `None` values
+            from the dictionary, which are hidden in the nested dictionaries.
+
         Returns:
             Dict[str, Any]: Report as dictionary by using the `.dict()` option of
                  pydantic. `None` is excluded.
         """
-        return ReportAPI(
+        report = ReportAPI(
             input=self.make_input_contribution,
             solver=self.make_solver_contribution,
             output=self.make_output_contribution,
-        ).dict(exclude_none=True)
+        ).model_dump(exclude_none=True)
+        report = exclude_none_dictionary(report)
+        report = transform_nested_types(report)
+        return report
 
 
 class SpectraFitNotebook(DataFramePlot, DataFrameDisplay, ExportResults):
@@ -877,13 +933,15 @@ class SpectraFitNotebook(DataFramePlot, DataFrameDisplay, ExportResults):
         self.export_args_df = FnameAPI(fname=fname, folder=folder, suffix="csv")
         self.export_args_out = FnameAPI(fname=fname, folder=folder, suffix="lock")
 
-        self.args_solver: Dict[str, Any] = {}
+        self.settings_solver_models: SolverModelsAPI = SolverModelsAPI()
         self.pre_statistic: Dict[str, Any] = {}
 
     @property
     def pre_process(self) -> None:
         """Pre-processing class."""
-        self.df, _pre_statistic = PreProcessing(df=self.df, args=self.args_pre.dict())()
+        self.df, _pre_statistic = PreProcessing(
+            df=self.df, args=self.args_pre.model_dump()
+        )()
         self.pre_statistic = _pre_statistic["data_statistic"]
         self.df_pre = self.df.copy()
 
@@ -944,6 +1002,13 @@ class SpectraFitNotebook(DataFramePlot, DataFrameDisplay, ExportResults):
             self.export_args_df.prefix = "metric"
             self.export_df(df=self.df_metric, args=self.export_args_df)
 
+    @property
+    def export_df_peaks(self) -> None:
+        """Export the dataframe."""
+        if self.df_peaks.empty is False:
+            self.export_args_df.prefix = "peaks"
+            self.export_df(df=self.df_peaks, args=self.export_args_df)
+
     @property
     def plot_original_df(self) -> None:
         """Plot the original spectra."""
@@ -1007,6 +1072,7 @@ class SpectraFitNotebook(DataFramePlot, DataFrameDisplay, ExportResults):
                 description=self.args_desc,
                 initial_model=self.initial_model,
                 pre_processing=self.args_pre,
+                settings_solver_models=self.settings_solver_models,
                 fname=self.export_args_out,
                 args_out=self.args,
                 df_org=self.df_org,
@@ -1026,6 +1092,7 @@ class SpectraFitNotebook(DataFramePlot, DataFrameDisplay, ExportResults):
         conf_interval: Union[bool, Dict[str, Any]] = False,
         bar_criteria: Optional[Union[str, List[str]]] = None,
         line_criteria: Optional[Union[str, List[str]]] = None,
+        solver_settings: Optional[Dict[str, Any]] = None,
     ) -> None:
         """Solves the fit problem based on the proposed model.
 
@@ -1049,6 +1116,9 @@ class SpectraFitNotebook(DataFramePlot, DataFrameDisplay, ExportResults):
             line_criteria (Optional[Union[str, List[str]]], optional): Criteria for
                 the line plot. It is recommended to use attributes from
                 `regression metric` module. Defaults to None.
+            solver_settings (Optional[Dict[str, Any]], optional): Settings for
+                the solver models, which is split into settings for `minimizer` and
+                `optimizer`.  Defaults to None.
 
         !!! info: "About criteria"
 
@@ -1062,10 +1132,15 @@ class SpectraFitNotebook(DataFramePlot, DataFrameDisplay, ExportResults):
         self.initial_model = initial_model
 
         if isinstance(conf_interval, bool):
-            conf_interval = ConfIntervalAPI().dict() if conf_interval is True else False
+            conf_interval = (
+                ConfIntervalAPI().model_dump() if conf_interval is True else False
+            )
         elif isinstance(conf_interval, dict):
             conf_interval = ConfIntervalAPI(**conf_interval).dict(exclude_none=True)
 
+        if solver_settings is not None and isinstance(solver_settings, dict):
+            self.settings_solver_models = SolverModelsAPI(**solver_settings)
+
         self.df_fit, self.args = PostProcessing(
             self.df,
             {
@@ -1079,6 +1154,7 @@ class SpectraFitNotebook(DataFramePlot, DataFrameDisplay, ExportResults):
                     "column": list(self.df.columns),
                     "autopeak": self.autopeak,
                     **list2dict(peak_list=self.initial_model),
+                    **self.settings_solver_models.model_dump(),
                 },
             )(),
         )()
