@@ -17,12 +17,16 @@ from spectrafit.tools import pkl2any
 from spectrafit.tools import pure_fname
 
 
-choices_fformat = {"latin1", "utf-8", "utf-16", "utf-32"}
-choices_export = {"png", "pdf", "jpg", "jpeg"}
-
-
 class PklVisualizer(Converter):
-    """Visualize the pkl data as a graph."""
+    """Visualize the pkl data as a graph.
+
+    Attributes:
+        choices_fformat (Set[str]): The choices for the file format.
+        choices_export (Set[str]): The choices for the export format.
+    """
+
+    choices_fformat = {"latin1", "utf-8", "utf-16", "utf-32"}
+    choices_export = {"png", "pdf", "jpg", "jpeg"}
 
     def get_args(self) -> Dict[str, Any]:
         """Get the arguments from the command line.
@@ -32,7 +36,8 @@ class PklVisualizer(Converter):
                 additional information beyond the command line arguments.
         """
         parser = argparse.ArgumentParser(
-            description="Converter for 'SpectraFit' from pkl files to a graph."
+            description="Converter for 'SpectraFit' from pkl files to a graph.",
+            usage="%(prog)s [options] infile",
         )
         parser.add_argument(
             "infile",
@@ -46,7 +51,7 @@ class PklVisualizer(Converter):
             " Default is 'latin1'.",
             type=str,
             default="latin1",
-            choices=choices_fformat,
+            choices=self.choices_fformat,
         )
         parser.add_argument(
             "-e",
@@ -54,7 +59,7 @@ class PklVisualizer(Converter):
             help="File extension for the graph export.",
             type=str,
             default="pdf",
-            choices=choices_export,
+            choices=self.choices_export,
         )
 
         return vars(parser.parse_args())
@@ -98,7 +103,7 @@ class PklVisualizer(Converter):
         Raises:
             ValueError: If the export format is not supported.
         """
-        if export_format.lower() not in choices_export:
+        if export_format.lower() not in self.choices_export:
             raise ValueError(f"Export format '{export_format}' is not supported.")
 
         plt.savefig(
