@@ -1,4 +1,5 @@
 """Collection of essential tools for running SpectraFit."""
+
 import gzip
 import json
 import pickle
@@ -18,7 +19,7 @@ import tomli
 import yaml
 
 from lmfit import Minimizer
-from lmfit import conf_interval
+from lmfit.confidence import ConfidenceInterval
 from lmfit.minimizer import MinimizerException
 from spectrafit.api.tools_model import ColumnNamesAPI
 from spectrafit.models import calculated_model
@@ -57,7 +58,7 @@ class PreProcessing:
         """
         df_copy: pd.DataFrame = self.df.copy()
         self.args["data_statistic"] = df_copy.describe(
-            percentiles=np.arange(0.1, 1.0, 0.1)
+            percentiles=np.arange(0.1, 1.0, 0.1).tolist()
         ).to_dict(orient="split")
         try:
             if isinstance(self.args["energy_start"], (int, float)) or isinstance(
@@ -93,7 +94,7 @@ class PreProcessing:
         energy_start: Union[int, float] = args["energy_start"]
         energy_stop: Union[int, float] = args["energy_stop"]
 
-        df_copy: pd.DataFrame = df.copy()
+        df_copy = df.copy()
         if isinstance(energy_start, (int, float)) and isinstance(
             energy_stop, (int, float)
         ):
@@ -252,9 +253,11 @@ class PostProcessing:
         if self.args["global_"]:
             return df.rename(
                 columns={
-                    col: ColumnNamesAPI().energy
-                    if i == 0
-                    else f"{ColumnNamesAPI().intensity}_{i}"
+                    col: (
+                        ColumnNamesAPI().energy
+                        if i == 0
+                        else f"{ColumnNamesAPI().intensity}_{i}"
+                    )
                     for i, col in enumerate(df.columns)
                 }
             )
@@ -284,13 +287,25 @@ class PostProcessing:
 
         """
         self.args["fit_insights"] = fit_report_as_dict(
-            self.result, modelpars=self.result.params
+            inpars=self.result, settings=self.minimizer, modelpars=self.result.params
         )
         if self.args["conf_interval"]:
             try:
-                self.args["confidence_interval"] = conf_interval(
+                _min_rel_change = self.args["conf_interval"].pop("min_rel_change", None)
+                ci = ConfidenceInterval(
                     self.minimizer, self.result, **self.args["conf_interval"]
                 )
+                if _min_rel_change is not None:
+                    ci.min_rel_change = _min_rel_change
+                    self.args["conf_interval"]["min_rel_change"] = _min_rel_change
+
+                trace = self.args["conf_interval"].get("trace")
+
+                if trace is True:
+                    self.args["confidence_interval"] = (ci.calc_all_ci(), ci.trace_dict)
+                else:
+                    self.args["confidence_interval"] = ci.calc_all_ci()
+
             except (MinimizerException, ValueError, KeyError) as exc:
                 print(f"Error: {exc} -> No confidence interval could be calculated!")
                 self.args["confidence_interval"] = {}
@@ -395,7 +410,7 @@ class PostProcessing:
     def export_desprective_statistic2args(self) -> None:
         """Export the descriptive statistic of the spectra, fit, and contributions."""
         self.args["descriptive_statistic"] = self.df.describe(
-            percentiles=np.arange(0.1, 1, 0.1)
+            percentiles=np.arange(0.1, 1, 0.1).tolist()
         ).to_dict(orient="split")
 
 
@@ -463,7 +478,7 @@ class SaveResult:
                  additional information beyond the command line arguments.
         """
         self.df = df
-        self.args = args
+        self.args = transform_nested_types(args)
 
     def __call__(self) -> None:
         """Call the SaveResult class."""
@@ -481,15 +496,15 @@ class SaveResult:
                 2. The `correlation analysis` of the optimization process.
                 3. The `error analysis` of the optimization process.
         """
-        self.df.to_csv(Path(f"{self.args['outfile']}_fit.csv"), index=False)
-        print(self.args["fit_insights"]["variables"])
+        _fname = Path(f"{self.args['outfile']}_fit.csv")
+        self.df.to_csv(_fname, index=False)
         pd.DataFrame(**self.args["linear_correlation"]).to_csv(
             Path(f"{self.args['outfile']}_correlation.csv"),
             index=True,
             index_label="attributes",
         )
         pd.DataFrame.from_dict(self.args["fit_insights"]["variables"]).to_csv(
-            Path(f"{self.args['outfile']}_errors.csv"),
+            Path(f"{self.args['outfile']}_components.csv"),
             index=True,
             index_label="attributes",
         )
@@ -500,7 +515,7 @@ class SaveResult:
             with open(
                 Path(f"{self.args['outfile']}_summary.json"), "w", encoding="utf-8"
             ) as f:
-                json.dump(self.args, f, indent=4)
+                json.dump(transform_nested_types(self.args), f, indent=4)
         else:
             raise FileNotFoundError("No output file provided!")
 
@@ -529,7 +544,7 @@ def read_input_file(fname: Path) -> MutableMapping[str, Any]:
     elif fname.suffix == ".json":
         with open(fname, encoding="utf-8") as f:
             args = json.load(f)
-    elif fname.suffix in [".yaml", ".yml"]:
+    elif fname.suffix in {".yaml", ".yml"}:
         with open(fname, encoding="utf-8") as f:
             args = yaml.load(f, Loader=yaml.FullLoader)
     else:
@@ -668,3 +683,53 @@ def pure_fname(fname: Path) -> Path:
     """
     _fname = fname.parent / fname.stem
     return pure_fname(_fname) if _fname.suffix else _fname
+
+
+def exclude_none_dictionary(value: Dict[str, Any]) -> Dict[str, Any]:
+    """Exclude `None` values from the dictionary.
+
+    Args:
+        value (Dict[str, Any]): Dictionary to be processed to
+            exclude `None` values.
+
+    Returns:
+        Dict[str, Any]: Dictionary without `None` values.
+    """
+    if isinstance(value, list):
+        return [exclude_none_dictionary(v) for v in value if v is not None]
+    elif isinstance(value, dict):
+        return {
+            k: exclude_none_dictionary(v) for k, v in value.items() if v is not None
+        }
+    else:
+        return value
+
+
+def transform_nested_types(value: Dict[str, Any]) -> Dict[str, Any]:
+    """Transform nested types numpy values to python values.
+
+    Args:
+        value (Dict[str, Any]): Dictionary to be processed to
+            transform numpy values to python values.
+
+    Returns:
+        Dict[str, Any]: Dictionary with python values.
+    """
+    if isinstance(value, list):
+        return [transform_nested_types(v) for v in value]
+    elif isinstance(value, tuple):
+        return tuple(transform_nested_types(v) for v in value)
+    elif isinstance(value, dict):
+        return {k: transform_nested_types(v) for k, v in value.items()}
+    elif isinstance(value, np.ndarray):
+        return transform_nested_types(value.tolist())
+    elif isinstance(value, np.int32):
+        return int(value)
+    elif isinstance(value, np.int64):
+        return int(value)
+    elif isinstance(value, np.bool_):
+        return bool(value)
+    elif isinstance(value, np.float64):
+        return float(value)
+    else:
+        return value
